@@ -29,8 +29,7 @@ class TrialEvalCallback(EvalCallback):
         verbose: int = 0,
         best_model_save_path: Optional[str] = None,
         log_path: Optional[str] = None,
-    ):
-
+    ) -> None:
         super().__init__(
             eval_env=eval_env,
             n_eval_episodes=n_eval_episodes,
@@ -103,12 +102,12 @@ class ParallelTrainCallback(BaseCallback):
 
     TODO:
     - blocking mode: wait for the model to finish updating the policy before collecting new experience
-        at the end of a rollout
+    at the end of a rollout
     - force sync mode: stop training to update to the latest policy for collecting
-        new experience
+    new experience
 
     :param gradient_steps: Number of gradient steps to do before
-        sending the new policy
+      sending the new policy
     :param verbose: Verbosity level
     :param sleep_time: Limit the fps in the thread collecting experience.
     """
@@ -191,7 +190,7 @@ class ParallelTrainCallback(BaseCallback):
         if self._model_ready:
             self._model.replay_buffer = deepcopy(self.model.replay_buffer)
             self.model.set_parameters(deepcopy(self._model.get_parameters()))
-            self.model.actor = self.model.policy.actor  # type: ignore[union-attr, attr-defined]
+            self.model.actor = self.model.policy.actor  # type: ignore[union-attr, attr-defined, assignment]
             if self.num_timesteps >= self._model.learning_starts:
                 self.train()
             # Do not wait for the training loop to finish
