@@ -12,6 +12,11 @@ try:
     import highway_env  # pytype: disable=import-error
 except ImportError:
     highway_env = None
+else:
+    # hotfix for highway_env
+    import numpy as np
+
+    np.float = np.float32  # type: ignore[attr-defined]
 
 try:
     import neck_rl  # pytype: disable=import-error
