@@ -1,3 +1,9 @@
 from rl_zoo3.plots.all_plots import all_plots
 from rl_zoo3.plots.plot_from_file import plot_from_file
 from rl_zoo3.plots.plot_train import plot_train
+
+__all__ = [
+    "all_plots",
+    "plot_from_file",
+    "plot_train",
+]
