@@ -130,13 +130,6 @@ def train() -> None:
         help="Custom yaml file or python package from which the hyperparameters will be loaded."
         "We expect that python packages contain a dictionary called 'hyperparams' which contains a key for each environment.",
     )
-    parser.add_argument(
-        "-yaml",
-        "--yaml-file",
-        type=str,
-        default=None,
-        help="This parameter is deprecated, please use `--conf-file` instead",
-    )
     parser.add_argument("-uuid", "--uuid", action="store_true", default=False, help="Ensure that the run has a unique ID")
     parser.add_argument(
         "--track",
@@ -166,11 +159,6 @@ def train() -> None:
     env_id = args.env
     registered_envs = set(gym.envs.registry.env_specs.keys())  # pytype: disable=module-attr
 
-    if args.yaml_file is not None:
-        raise ValueError(
-            "The`--yaml-file` parameter is deprecated and will be removed in RL Zoo3 v1.8, please use `--conf-file` instead",
-        )
-
     # If the environment is not found, suggest the closest match
     if env_id not in registered_envs:
         try:
@@ -204,13 +192,13 @@ def train() -> None:
     if args.track:
         try:
             import wandb
-        except ImportError:
+        except ImportError as e:
             raise ImportError(
                 "if you want to use Weights & Biases to track experiment, please install W&B via `pip install wandb`"
-            )
+            ) from e
 
         run_name = f"{args.env}__{args.algo}__{args.seed}__{int(time.time())}"
-        tags = args.wandb_tags + [f"v{sb3.__version__}"]
+        tags = [*args.wandb_tags, f"v{sb3.__version__}"]
         run = wandb.init(
             name=run_name,
             project=args.wandb_project_name,
